@@ -3,17 +3,22 @@ from logging import getLogger
 logger = getLogger(__name__)
 
 RECIPE_DEFAULTS = {'require-administrative-privileges': 'true',
-                   'dependent-scripts': 'true',
+                   'dependent-scripts': 'false',
+                   'shrink-cache-dist': 'true',
                    'eggs': '',
                    'scripts': '',
+                   'gui-scripts': '',
                    'deb-dependencies': '',
+                   'rpm-dependencies': '',
                    'sign-executables-and-msi': 'false',
                    'pfx-file': '~/.authenticode/certificate.pfx',
                    'pfx-password-file': '~/.authenticode/certificate-password.txt',
                    'timestamp-url':  "http://timestamp.verisign.com/scripts/timstamp.dll",
                    'add-remove-programs-icon': None,
+                   'shortcuts-icon': None,
                    'msi-banner-bmp': None,
                    'msi-dialog-bmp': None,
+                   'startmenu-shortcuts': [],
                   }
 
 class PackagingRecipe(object):
@@ -87,9 +92,12 @@ class PackagingRecipe(object):
     def get_eggs_for_production(self):
         return self._get_recipe_atribute("eggs")
 
-    def get_scripts_for_production(self):
+    def get_console_scripts_for_production(self):
         return self._get_recipe_atribute("scripts")
 
+    def get_gui_scripts_for_production(self):
+        return self._get_recipe_atribute("gui-scripts")
+
     def get_require_administrative_privileges(self):
         return self._get_recipe_atribute("require-administrative-privileges")
 
@@ -172,6 +180,10 @@ class PackagingRecipe(object):
         key = 'sign-executables-and-msi'
         return self.get_recipe_section().get(key, RECIPE_DEFAULTS[key]) in [True, 'true', 'True']
 
+    def should_shrink_cache_dist(self):
+        key = 'shrink-cache-dist'
+        return self.get_recipe_section().get(key, RECIPE_DEFAULTS[key]) in [True, 'true', 'True']
+
     def get_pfx_file(self):
         from os.path import normpath, expanduser
         key = 'pfx-file'
@@ -199,10 +211,33 @@ class PackagingRecipe(object):
     def get_msi_dialog_bmp(self):
         return self._get_resource_file_from_recipe_section('msi-dialog-bmp')
 
+    def get_shortcuts_icon(self):
+        return self._get_resource_file_from_recipe_section("shortcuts-icon")
+
+    def get_startmenu_shortcuts(self):
+        return self._get_recipe_atribute("startmenu-shortcuts")
+
     def write_buildout_configuration_file_for_production(self):
         from .. import utils, assertions
         method = utils.buildout.write_buildout_configuration_file_for_production
         return method(self.get_dependent_scripts(),
                       self.get_eggs_for_production() or self.get_python_module_name(),
-                      self.get_scripts_for_production(),
-                      self.get_require_administrative_privileges())
\ No newline at end of file
+                      self.get_console_scripts_for_production(),
+                      self.get_gui_scripts_for_production(),
+                      self.get_require_administrative_privileges())
+
+    def delete_non_production_packages_from_cache_dist(self):
+        from ..utils import get_dependencies, get_distributions_from_dependencies
+        from glob import glob
+        from os import path, remove
+        if not self.should_shrink_cache_dist():
+            return
+        eggs = self.get_eggs_for_production().split() or [self.get_python_module_name()]
+        dependencies = set.union(*[get_dependencies(name) for name in eggs])
+        distributions = get_distributions_from_dependencies(dependencies)
+        for filepath in glob(path.join(self.get_download_cache_dist(), '*')):
+            basename = path.basename(filepath).lower()
+            if any([distname.lower() in basename and version.replace('-', '_') in basename.replace('-', '_')
+                   for distname, version in distributions.items()]):
+                continue
+            remove(filepath)
